<template>
	<!-- 流域管理 -->
  <div class="bbsl-common-page" @click="commonPageClick">
    <div class="bbsl-table-search">
      <el-form v-model="queryParam" :inline="true">
        <el-row :gutter="10">
          <el-col :span="6">
            <el-form-item label="流域名称">
              <el-input
                clearable
                size="mini"
                placeholder="请输入流域名称"
                v-model="queryParam.params.basName"
              ></el-input>
            </el-form-item>
          </el-col> 
          <el-col :span="6">
              <el-form-item label="流域级别">
                <el-select
                  @change="changebasGrad"
                  size="mini"
                  v-model="queryParam.params.basGard"
                  clearable
                  placeholder="请选择流域级别"
                >
                  <el-option
                    v-for="item in basGrads"
                    :key="item.id"
                    :label="item.name"
                    :value="item.value"
                  ></el-option>
                </el-select>
              </el-form-item>
            </el-col>
          <el-col :span="7">
            <el-form-item label="行政区划">
              <el-cascader
                size="mini"
                :options="basAdNames"
                v-model="queryParam.params.basAdCode"
                :props="setKesLabel"
                @change="onhouChange"
              >
                <template slot-scope="{node, data}">
                  <span>{{ data.name }}</span>
                  <span v-if="!node.isLeaf">
                    ({{ data.children === [] ? '' : data.children.length }})
                  </span>
                </template>
              </el-cascader>
            </el-form-item>
          </el-col>
          <el-col :span="5">
            <el-form-item>
              <el-button
                type="primary"
                icon="el-icon-search"
                size="mini"
                @click="onClickSearch"
                >搜索</el-button
              >
              <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
                >重置</el-button
              >
              <el-button type="text" @click.stop="openMore"
                >更多
                <i
                  :class="showMore ? 'el-icon-arrow-up' : 'el-icon-arrow-down'"
                ></i
              ></el-button>
            </el-form-item>
          </el-col>
        </el-row>
        <div class="bbsl-search-more" style="width:250px" v-if="showMore">
          <el-row>
            <el-col :span="24">
              <el-form-item label="跨界类型">
                <el-select
                  @change="changecrOverType"
                  size="mini"
                  v-model="queryParam.params.crOverType"
                  clearable
                  placeholder="请选择跨界类型："
                >
                  <el-option
                    v-for="item in crOverTypes"
                    :key="item.id"
                    :label="item.name"
                    :value="item.value"
                  ></el-option>
                </el-select>
              </el-form-item>
            </el-col>
          </el-row>
        </div>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
        <el-button
          size="mini"
          icon="el-icon-plus"
          type="primary"
          @click="openFormDiao"
          >新增</el-button
        >
        <el-button
          :disabled="!multipleSelection.length"
          size="mini"
          icon="el-icon-delete"
          type="danger"
          @click="deleteSelect"
          >删除</el-button
        >
      </div>
      <el-table
        stripe
        size="mini"
        :max-height="tableMaxHeight"
        @row-dblclick="handleDbClick"
        :style="{width: '100%'}"
        ref="multipleSelection"
        v-loading="loading"
        border
        :data="tableData"
        :row-key="getRowKey"
        @selection-change="handleSelectionChange"
        :header-cell-style="{'text-align': 'center'}"
        :cell-style="{'text-align': 'center'}"
      >
        <el-table-column
          type="selection"
          width="55"
          :reserve-selection="true"
        ></el-table-column>
        <el-table-column
          min-width="120"
          sortable
          prop="basName"
          label="流域名称"
          show-overflow-tooltip
        ></el-table-column>
        <el-table-column
          min-width="160"
          sortable
          prop="basArea"
          label="流域面积(km2)"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          min-width="140"
          sortable
          prop="basCode"
          label="流域代码"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          min-width="140"
          sortable
          prop="basGrad"
          label="流域级别"
          show-overflow-tooltip
        >
        </el-table-column>
        <el-table-column
          min-width="150"
          sortable
          prop="basAdName"
          label="流域所属行政区"
          show-overflow-tooltip
        ></el-table-column>
      </el-table>
      <el-pagination
        ref="paginationPanel"
        align="right"
        class="bbsl-pagination"
        background
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParam.pageBean.page"
        :page-sizes="[5, 10, 20, 50]"
        :page-size="queryParam.pageBean.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="total"
      ></el-pagination>
    </div>
    <form-dialog
      v-if="showFormDia"
      @closeFormDiao="closeFormDiao"
      @refList="getDateList"
      :showFormDia="showFormDia"
      :title="title"
      :pId="pId"
    ></form-dialog>
  </div>
</template>
<script>
import FormDialog from './components/form-dialog.vue'
import basin from '@/api/basin.js'
import req from '@/request.js'
import {TableMixin} from '@/mixins/tableMixin'
export default {
  name: 'resManager',
  components: {
    FormDialog,
  },
  mixins: [TableMixin],
  data() {
    return {
      loading: false,
      multipleSelection: [], // 复选框
      queryParam: {
        pageBean: {
          pageSize: 10,
          page: 1,
        },
        params: {
          basName: null, // 流域
          basAdCode: null, // 流域所属行政区
          basGard: null, //流域级别
          crOverType: null, //跨界类型
        },
      },
      total: 0,
      title: '',
      showFormDia: false,
      tableData: [],
      pId: '',
      errMessage: '',
      errorFileUrl: '',
      basAdNames: [], //行政区
      lookDetailDia: false, // 详情弹层
      codes: {codes: 'gkglbm'},
      crOverTypes: [], //跨界类型
      basGrads: [], //流域级别
      setKesLabel: {
        value: 'code',
        label: 'name',
        children: 'children',
      },
    }
  },
  created() {
    this.getSysDict()
    this.getDateList()
    // 行政区查询
    basin.getbasAdName({}, (res) => {
      this.basAdNames = res.value
    })
  },
  methods: {
    openMore() {
      this.showMore = !this.showMore
    },
    changebasGrad(val) {
      if (val) {
        this.queryParam.params.basGard = val
      } else {
        this.queryParam.params.basGard = null
      }
    },
    changecrOverType(val) {
      if (val) {
        this.queryParam.params.crOverType = val
      } else {
        this.queryParam.params.crOverType = null
      }
    },
    //获取字典数据
    getSysDict() {
      let portal = window.context.portal
      return new Promise((resolve, reject) => {
        req.post(portal + '/sys/sysDictionary/v1/queryAllDictItems').then(
          (response) => {
            resolve(response.data)
            this.crOverTypes = response.data.kjlx
            this.basGrads = response.data.lyjb
            this.getDateList()
          },
          (error) => {
            reject(error)
          }
        )
      })
    },
    onhouChange(val) {
      if (val) {
        this.queryParam.params.basAdCode = val.toString()
      } else {
        this.queryParam.params.basAdCode = null;
      }
    },
    RemoveValByIndex(arr, index) {
      arr.splice(index, 1)
    },
    getDateList() {
      this.loading = true
      this.tableData = []
      basin.ListGet(this.queryParam, (res) => {
        this.tableData = res.rows
        this.total = res.total
        this.loading = false
      })
    },
    openFormDiao() {
      this.title = '新增'
      this.showFormDia = true;
    },
    closeFormDiao() {
      this.showFormDia = false
      this.getDateList()
    },
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.getDateList()
    },
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.getDateList()
    },
    // // 修改
    handleUpdate(row) {
      this.title = '修改';
      this.pId = row.id;
      this.showFormDia = true;
    },
    handleSelectionChange(val) {
      this.multipleSelection = val.map((item) => {
        return item.id
      })
    },
    // // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    // // 批量删除
    deleteSelect() {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      }).then(() => {basin.remove(this.multipleSelection, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                // this.multipleSelection = [];
                this.$refs.multipleSelection.clearSelection()
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => {})
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$confirm('确定删除选中数据？', '提示', {
        confirmButtonText: '确 定',
        cancelButtonText: '取 消',
        type: 'warning',
      })
        .then(() => {
          basin
            .remove(row.id, (res) => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: '删除成功',
                  duration: 2000,
                  // offset: 80
                })
                this.queryParam.pageBean.page = 1
                this.getDateList()
              }
            })
            .catch((res) => {
              this.$notify({
                type: 'error',
                message: res.message,
                duration: 2000,
                offset: 80,
              })
              this.getDateList()
            })
        })
        .catch(() => {})
    },
    // // 点击查询
    onClickSearch() {
      this.queryParam.pageBean.page = 1
      this.getDateList()
    },
    // 重置
    resetQuery() {
      this.queryParam.params = {}
      this.onClickSearch()
    },
  },
}
</script>
<style lang="scss" scoped>
.btn-content {
  display: flex;
}
.el-select-dropdown__item span {
  color: rgb(51, 51, 51) !important;
}
.el-select-dropdown__item {
  color: #9a9a9a !important;
}
.el-select-dropdown__item.hover,
.el-select-dropdown__item:hover {
  background: #f5f7fa;
}
.btn-content :first-child {
  margin: 0 0 0 0 !important;
}
// ::v-deep .el-table__body-wrapper::-webkit-scrollbar {
//   width: 6px;
//   height: 15px;
// }
.sampling {
  ::v-deep .el-dialog__body {
    padding: 30px 20px 0 20px;
  }
}
::-webkit-scrollbar {
  background: #fff !important;
}
.bbsl-pagination{
  bottom:10px !important;
}
</style>
